package com.jqtx.windows.component.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.extra.cglib.CglibUtil;
import com.jqtx.windows.component.OverduedComponent;
import com.jqtx.windows.component.enums.OverDuedTypeEnum;
import com.jqtx.windows.component.model.OverduedModel;
import com.jqtx.windows.repository.entity.WindowsOverdued;
import com.jqtx.windows.repository.entity.WindowsOverduedExample;
import com.jqtx.windows.repository.mapper.WindowsOverduedMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.List;

@Service
public class OverduedComponentImpl implements OverduedComponent {

    @Autowired
    private WindowsOverduedMapper windowsOverduedMapper;


    @Override
    public void insert(OverduedModel model) {
        WindowsOverduedExample example = new WindowsOverduedExample();
        WindowsOverduedExample.Criteria criteria = example.createCriteria();
        criteria.andLoanNoEqualTo(model.getLoanNo());
        criteria.andPlanNoEqualTo(model.getPlanNo());
        List<WindowsOverdued> windowsOverdueds = windowsOverduedMapper.selectByExample(example);
        if (windowsOverdueds == null || windowsOverdueds.size() == 0) {
            windowsOverduedMapper.insertSelective(CglibUtil.copy(model, WindowsOverdued.class));
        }
    }

    @Override
    public int updateOverduedModel(OverduedModel model) {
        WindowsOverduedExample example = new WindowsOverduedExample();
        WindowsOverduedExample.Criteria criteria = example.createCriteria();
        criteria.andIdEqualTo(model.getId());
        WindowsOverdued windowsOverdued = BeanUtil.toBean(model, WindowsOverdued.class);
        int i = windowsOverduedMapper.updateByExampleSelective(windowsOverdued, example);
        return i;
    }

    @Override
    public void updateOverduedByLoanNo(String loanNo, String repayDate) {
        WindowsOverduedExample example = new WindowsOverduedExample();
        WindowsOverduedExample.Criteria criteria = example.createCriteria();
        criteria.andLoanNoEqualTo(loanNo);
        List<WindowsOverdued> windowsOverdueds = windowsOverduedMapper.selectByExample(example);
        if (windowsOverdueds != null && windowsOverdueds.size() > 0) {
            windowsOverdueds.forEach(e -> {
                e.setStatus(OverDuedTypeEnum.COLLECT.getCode());
                e.setBackDate(LocalDate.parse(repayDate, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")));
                windowsOverduedMapper.updateByPrimaryKey(e);
            });
        }
    }

    @Override
    public void updateOverduedByPlanNo(String planNo, String repayDate) {
        WindowsOverduedExample example = new WindowsOverduedExample();
        WindowsOverduedExample.Criteria criteria = example.createCriteria();
        criteria.andPlanNoEqualTo(planNo);
        List<WindowsOverdued> windowsOverdueds = windowsOverduedMapper.selectByExample(example);
        if (windowsOverdueds != null && windowsOverdueds.size() > 0) {
            windowsOverdueds.forEach(e -> {
                e.setStatus(OverDuedTypeEnum.COLLECT.getCode());
                e.setBackDate(LocalDate.parse(repayDate, DateTimeFormatter.ofPattern("yyyy-MM-dd")));
                windowsOverduedMapper.updateByPrimaryKey(e);
            });
        }
    }
}
